import os
import random
from typing import List


def random_proxy() -> str:
    """Returns a random proxy (ip:port) from the currently configured list."""
    proxy_list = _open_proxy_list()
    random_proxy = random.choice(proxy_list)

    return random_proxy


def list_proxies() -> List[str]:
    """Lists all proxies from the currently configured list."""
    proxy_list = _open_proxy_list()

    return proxy_list


def _open_proxy_list():
    """Opens the current proxy list text file."""
    proxy_filepath = os.path.join('proxlist', 'data', 'proxy_list.txt')
    with open(proxy_filepath, 'r') as filename:
        data = filename.readlines()
        proxy_list = [line_item.replace('\n', '').strip() for line_item in data]

    return proxy_list



import proxlist


def test_random_proxy():
    proxy_list = proxlist.proxies._open_proxy_list()
    random_proxy = proxlist.random_proxy()

    assert random_proxy in proxy_list


def test_list_proxies():
    proxy_list = proxlist.proxies._open_proxy_list()
    retrieved_proxy_list = proxlist.list_proxies()

    assert retrieved_proxy_list == proxy_list


def test_open_proxy_list():
    proxy_list = proxlist.proxies._open_proxy_list()

    assert type(proxy_list) == list
    assert len(proxy_list) > 10
